import * as React from 'react';
import { Icon, Step, Button, Table, Radio, Form } from 'semantic-ui-react';
import { Grid, Image, Label, Segment, Dropdown } from 'semantic-ui-react';


export class SensorConfiguration extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }


  render() {
    let steps = [<CrawlerSelector />, <SensorItemSelector />, <ETCSelector />];

    return (
      <ConfigStepper steps={steps} />
    );
  }
}


export class ConfigStepper extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      currentStep: 1,
    };
  }

  handleActive(idx: number): boolean {
    if (this.state.currentStep === idx) {
      return true;
    }
    return false;
  }

  handleCompleted(idx: number): boolean {
    if (this.state.currentStep > idx) {
      return true;
    }
    return false;
  }

  handlePrev(event: React.SyntheticEvent<HTMLAnchorElement>, data: object) {
    let step: number = this.state.currentStep;
    if (step <= 1) {
      step = 1;
    } else {
      step--;
    }
    this.setState({
      currentStep: step,
    });
  }
  handleNext(event: React.SyntheticEvent<HTMLAnchorElement>, data: object) {
    let step: number = this.state.currentStep;
    if (step >= this.props.steps.length + 1) {
      step = this.props.steps.length + 1;
    } else {
      step++;
    }
    this.setState({
      currentStep: step,
    });
    if (step === this.props.steps.length + 1) {
      console.log("Done");
    }
  }

  showContent() {
    return this.props.steps[this.state.currentStep - 1];
  }

  checkPrevDisabled(): boolean {
    if (this.state.currentStep <= 1) {
      return true;
    } else {
      return false;
    }
  }

  checkNextDisabled(): boolean {
    if (this.state.currentStep === this.props.steps.length + 1) {
      return true;
    } else {
      return false;
    }
  }

  render() {
    return (
      <div>
        <Step.Group>
          <Step active={this.handleActive(1)} completed={this.handleCompleted(1)}>
            <Icon name='settings' />
            <Step.Content title='Step 1' description='골라골라 크롤러를 골라' />
          </Step>

          <Step active={this.handleActive(2)} completed={this.handleCompleted(2)}>
            <Icon name='list ul' />
            <Step.Content title='Step 2' description='골라골라 아이템도 골라' />
          </Step>

          <Step active={this.handleActive(3)} completed={this.handleCompleted(3)}>
            <Icon name='options' />
            <Step.Content title='Step 3' description='나머지도 골라 아 빨리' />
          </Step>
        </Step.Group>
        <br />
        {this.showContent()}
        <br />
        <Button.Group floated={'right'}>
          <Button onClick={this.handlePrev.bind(this)} disabled={this.checkPrevDisabled()}>Prev</Button>
          <Button.Or />
          <Button positive onClick={this.handleNext.bind(this)} disabled={this.checkNextDisabled()} >Next</Button>
        </Button.Group>

      </div>
    );
  }
}


export class CrawlerSelector extends React.Component<any, any> {

  private crawlers: object[];

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selected: null,
    };
  }

  componentWillMount() {
    this.getMetaCrawlers();
  }

  getMetaCrawlers() {
    //todo. getting MetaCrawler list
    let crawlers = [
      {
        "id": "1",
        "name": "WMI",
        "description": "WMI DESCRIPTION"
      },
      {
        "id": "2",
        "name": "SNMP",
        "description": "SNMP DESCRIPTION"
      },
      {
        "id": "3",
        "name": "JMX",
        "description": "JMX DESCRIPTION"
      },
    ];

    let crawlerOptions = [];
    let crawler: any;
    for (crawler of crawlers) {
      var option = {
        key: crawler.id,
        text: crawler.name,
        value: crawler.name,
        icon: 'windows',
      };
      crawlerOptions.push(option);
    }

    this.crawlers = crawlerOptions;
  }

  handleCrawlerSelection(e: any, data: any) {
    this.setState({
      selected: data.value,
    });
  }


  render() {

    return (
      <div>
        <Grid columns={1}>
          <Grid.Column>
            <Segment raised>
              <Label color='red' ribbon>INFO</Label>
              <span>Choose a Crawler type.</span>
              <br />
              <br />
              <Dropdown openOnFocus
                placeholder='Select Crawler' selection options={this.crawlers} onChange={this.handleCrawlerSelection.bind(this)} />

              <CrawlerAuthInputs crawler={this.state.selected} />
            </Segment>
          </Grid.Column>
        </Grid>

      </div>
    );
  }
}

export class CrawlerAuthInputs extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }

  componentWillMount() {

  }

  render() {
    let elem = null;
    if (this.props.crawler === null) {
      elem = null;
    } else {
      elem =
        <div>CrawlerAuthInputs</div>;
    }

    return (
      <div>
        {elem}
      </div>
    );
  }
}


export class SensorItemSelector extends React.Component<any, any> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
    };
  }

  render() {
    return (
      <div>SensorItemSelector</div>
    );
  }
}

export class ETCSelector extends React.Component<any, any> {
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      interval: 5,
    };
  }
  handleIntervalChange = (e: any, { value }: any) => this.setState({ interval : value });

  render() {
    return (
      <Table celled={true}>
        <Table.Body>
          <Table.Row>
            <Table.Cell collapsing>
              Interval
            </Table.Cell>
            <Table.Cell>
              <Form.Field>
                <Radio
                  label='5 seconds'
                  name='radioGroup'
                  value='5'
                  checked={this.state.interval === '5'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
              <Form.Field>
                <Radio
                  label='10 seconds'
                  name='radioGroup'
                  value='10'
                  checked={this.state.interval === '10'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
              <Form.Field>
                <Radio
                  label='15 seconds'
                  name='radioGroup'
                  value='15'
                  checked={this.state.interval === '15'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Field>
            </Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Notification
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Warn Condition
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
        </Table.Body>
      </Table>
    );
  }
}
